@@ -16,6 +16,7 @@ void init_normalizer2(py::module &m);
 void init_parseerr(py::module &m);
 void init_parsepos(py::module &);
 void init_rbbi(py::module &);
+void init_regex(py::module &);
 void init_resbund(py::module &);
 void init_schriter(py::module &);
 void init_sortkey(py::module &);
@@ -35,10 +36,12 @@ void init_uloc(py::module &);
 void init_uniset(py::module &m);
 void init_unistr(py::module &);
 void init_unorm2(py::module &m);
+void init_uregex(py::module &m);
 void init_ures(py::module &m);
 void init_uscript(py::module &m);
 void init_uset(py::module &m);
 void init_ustring(py::module &);
+void init_utext(py::module &);
 void init_utrans(py::module &m);
 void init_utypes(py::module &);
 void init_uversion(py::module &);
@@ -83,6 +86,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_parseerr(m);
   init_parsepos(m);
   init_rbbi(m);
+  init_regex(m);
   init_resbund(m);
   init_schriter(m);
   init_sortkey(m);
@@ -102,10 +106,12 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_uniset(m);
   init_unistr(m);
   init_unorm2(m);
+  init_uregex(m);
   init_ures(m);
   init_uscript(m);
   init_uset(m);
   init_ustring(m);
+  init_utext(m);
   init_utrans(m);
   init_utypes(m);
   init_uversion(m);
