@@ -9,18 +9,18 @@ class _ConstVoidPtr {
 public:
   _ConstVoidPtr(std::nullptr_t value);
   _ConstVoidPtr(const char *value);
-  _ConstVoidPtr(py::object value);
+  _ConstVoidPtr(const py::object &value);
   _ConstVoidPtr(const void *value);
   // template <typename T> _ConstVoidPtr(T value);
   ~_ConstVoidPtr();
 
-  std::any get() const { return context_; }
+  std::any &get() { return context_; }
 
-  py::function get_action() const { return action_; }
+  py::function &get_action() { return action_; }
 
   bool has_value() const { return context_.has_value(); }
 
-  void set_action(py::function action) { action_ = action; }
+  void set_action(const py::function &action) { action_ = action; }
 
   const char *to_c_str() const;
 
